{% load i18n %}


    <div class="info_box" style="background-color: #f9f9f9;padding: 15px;">
      <div class="info_box_content html_text_with_imgs" style="font-size:12px;">
        {% if pd_with_header %}
        <p style="font-size:16px;font-weight: bold;margin-bottom:15px;">
          <i class="{{ participant.get_icon_class }}"></i> &nbsp;
          <a href="{{ participant.get_absolute_url}}" style="color:inherit;">{{ participant.name }} &nbsp;
          <i class="icon-arrow-right"></i></a>
        </p>
        {% endif %}
        {% if participant.belongs_to.count > 0 %}
          <p style="font-size:12px;">
            {% trans "Belongs to" %}:<br>
              {% for bt_participant in participant.belongs_to.all %}
                <a href="{{ bt_participant.get_absolute_url }}">{{ bt_participant }}</a><br>
              {% endfor %}
          </p>
        {% endif %}
        
        {{ participant.description|safe }}
        <div style="clear:both;height:1px;"></div>
        
      </div>
    </div>
