
{% if web_source_list %}
<div class="{% if size %}btn-group{% else %}dropdown{% endif %}" style="text-align: left;display:inline-block;">
  <a class="{% if size %}btn btn-{{ size }}{% endif %} dropdown-toggle" style="font-weight: normal;" data-toggle="dropdown" data-hover="dropdown" href="#">
    {{ web_source_list|length }} <i class="icon-globe"></i>{% if size %} <span class="caret"></span>{% endif %}
  </a>
  <ul class="dropdown-menu">
    {% for ws in web_source_list %}
      <li>
        <a href="{{ ws.url}}" target="_blank"><i class="{{ ws.get_icon_class }}"></i> {{ ws.title }}
          {% if ws.date %} ({{ ws.date|date:"d.m.Y" }}){% endif %}</a>
      </li>
    {% endfor %}
  </ul>
</div>&nbsp;&nbsp;
{% endif %}
