{% extends 'base.html' %}
{% load i18n %}

{% block title %} - {{ participant }}{% endblock %}

{% block content %}

{% trans "Participants" as ph_bc1 %}
{% trans "participants_url" as ph_bc1_url %}
{% trans "Participant" as ph_bc2 %}
{% with ph_icon="icon-group" ph_title=participant.name ph_bc1=ph_bc1 ph_bc1_url=ph_bc1_url ph_bc2=ph_bc2 %}
{% include "layout_elements/page_header.html" %}
{% endwith %}

</div>

<div class="row">
<div class="span6">
  
  <div class="section">
    {% include "info_box/participant_detail.html" %}
  </div>
  
  {% if document_list %}
    {% trans "Documents" as sh_title %}
    {% with sh_title=sh_title sh_ec_id="d_1" document_list=document_list %}
      {% include "info_box/documents.html" %}
    {% endwith %}
  {% endif %}
  
  {% with web_source_list=participant.web_sources.all %}
    {% include "info_box/web_sources.html" %}
  {% endwith %}
  
  {% if participant.to_memberships.count > 0 %}
    {% trans "Associated Participants" as sh_title %}
    {% with sh_title=sh_title sh_ec_id="ap_1" sh_icon="icon-user" sh_url_title="" %}
      {% include "layout_elements/section_header.html" %}
    {% endwith %}
    <div class="info_box" id="ap_1">
      {% with membership_list=participant.to_memberships.all %}
        {% include "info_box/memberships.html" %}
      {% endwith %}
    </div>
  {% endif %}
  
  {% if event_list.count > 0 %}
    {% trans "Events" as sh_title %}
    {% with sh_title=sh_title sh_icon="icon-time" sh_url_title="" %}
      {% include "layout_elements/event_section_header.html" %}
    {% endwith %}
    
    {% include "info_box/events.html" %}
  {% endif %}

</div>

<div class="span6">
  
  {% if question_list.count > 0 %}
    {% include "info_box/questions.html" %}
  {% endif %}

  {% if content_document_list %}
    {% trans "Document Contents" as sh_title %}
    {% with sh_title=sh_title sh_ec_id="d_2" document_list=content_document_list %}
      {% include "info_box/documents.html" %}
    {% endwith %}
  {% endif %}
  
  {% trans "Comments" as sh_title %}
  {% trans "New" as sh_url_title %}
  {% trans "comments_url" as comments_url %}
  {% with sh_title=sh_title sh_icon="icon-comments" sh_url_title=sh_url_title sh_url="#CommentModal" modal_url="yes" rss_url=comments_url|add:"rss/" %}
    {% include "layout_elements/section_header.html" %}
  {% endwith %}
  {% with form=comment_form form_valid=comment_form_valid commented_object1=participant %}
  {% include "dialogs/comment.html" %}
  {% endwith %}
  
  {% include "info_box/comments.html" %}
  
</div>

{% endblock %}
