{% extends 'base.html' %}
{% load i18n %}

{% block title %} - {% trans "Comments" %}{% endblock %}

{% block rss_url %}
<link rel="alternate" type="application/rss+xml"
   title="RSS" href="{{ request.get_full_path}}rss/" />
{% endblock %}

{% block content %}

{% if content_type == 'project_part' %}
{% trans "Project" as ph_bc1 %}
{% trans "project_url" as ph_bc1_url %}
{% trans "Project Part" as ph_bc2 %}
{% endif %}

{% if content_type == 'question' %}
{% trans "Questions" as ph_bc1 %}
{% trans "questions_url" as ph_bc1_url %}
{% trans "Question" as ph_bc2 %}
{% endif %}

{% if content_type == 'participant' %}
{% trans "Participants" as ph_bc1 %}
{% trans "participants_url" as ph_bc1_url %}
{% trans "Participant" as ph_bc2 %}
{% endif %}

{% if content_type == 'event' %}
{% trans "Events" as ph_bc1 %}
{% trans "events_url" as ph_bc1_url %}
{% trans "Event" as ph_bc2 %}
{% endif %}

{% if content_type == 'document' %}
{% trans "Documents" as ph_bc1 %}
{% trans "documents_url" as ph_bc1_url %}
{% trans "Document" as ph_bc2 %}
{% endif %}

{% if not content_type %}
{% with ph_icon='icon-home' ph_title='Home' ph_bc1=ph_bc1 ph_bc1_url=ph_bc1_url ph_bc2=ph_bc2 ph_bc2_url=commented_object.get_absolute_url %}
{% include "layout_elements/comments_header.html" %}
{% endwith %}
{% else %}
{% with ph_icon=commented_object.get_icon_class ph_title=ph_title ph_bc1=ph_bc1 ph_bc1_url=ph_bc1_url ph_bc2=ph_bc2 ph_bc2_url=commented_object.get_absolute_url %}
{% include "layout_elements/comments_header.html" %}
{% endwith %}
{% endif %}

</div>

<div class="row">

<div class="span6">

  {% trans "All Comments" as sh_title %}
  {% with sh_title=sh_title sh_icon="icon-comments" sh_url_title="" sh_url="#CommentModal" modal_url="yes" rss_url="rss/"  %}
    {% include "layout_elements/section_header.html" %}
  {% endwith %}
  
  {% include "info_box/comments.html" %}

</div>

<div class="span6">

</div>

{% endblock %}