{% load i18n %}

  <div class="section  events_{{ class_addon }}" id="events_{{ id_addon }}">
  
    <div class="info_box type_table">
      <div class="info_box_content">
        <p>
        {% if event_list %}
          <table class="table">
            {% for event in event_list %}
            <tr class="{% if not event.important %}tr_normal_event{% endif %}">
              <td 
                style="width:72px;text-align:center;">
                {% if event.not_exact %}({% endif %}{{ event.date|date:"d.m.Y" }}{% if event.not_exact %}){% endif %}
              </td>
              <td style="text-align: center; width:15px;">
                <i class="{{ event.get_event_type_icon }}"></i>
              </td>
              <td>
                <a href="{{ event.get_absolute_url }}">{{ event.title }}</a>
              </td>
            </tr>
            {% endfor %}
            <tr style="display: none;" class="no_events_tr">
              <td colspan="3">
                {% trans "No events available." %}
              </td>
            </tr>
          </table>
        {% else %}
          <span style="font-size:12px;">
          {% trans "No events available." %}
          </span>
        {% endif %}
        </p>
      </div>
    </div>
  
  </div>