{% extends 'base.html' %}
{% load i18n %}

{% block title %} - {% trans "Questions" %}{% endblock %}

{% block rss_url %}
<link rel="alternate" type="application/rss+xml"
   title="RSS" href="{{ request.get_full_path}}rss/" />
{% endblock %}

{% block content %}

{% trans "Questions" as ch_title %}
{% with ch_icon="icon-question-sign" ch_title=ch_title ch_bc1=ch_title %}
{% include "layout_elements/category_header.html" %}
{% endwith %}

</div>

<div class="row">

<div class="span6">

  <div class="section">
    {% include "info_box/site_category_detail.html" %}
  </div>
  
  {% include "layout_elements/ec_button_group.html" %}

  {% for mpp in main_project_part_list_left %}
    {% with ec_title=mpp ec_id=mpp.id ec_url="" ec_count=mpp.get_num_questions question_list=mpp.get_questions id_addon=mpp.id ec_box_include="info_box/questions.html" sh_title="" %}
      {% include "layout_elements/ec_header_box.html" %}
    {% endwith %}
  {% endfor %}

</div>

<div class="span6">
  
  {% trans "New Research Requests" as sh_title %}
  {% trans "research_requests_url" as rr_url %}
  {% with sh_title=sh_title sh_icon="icon-eye-open" sh_url_title="" rss_url=rr_url|add:"rss/" %}
    {% include "layout_elements/section_header.html" %}
  {% endwith %}
  
  {% with rr_with_ec="yes" %}
    {% include "info_box/research_requests.html" %}
  {% endwith %}
  
  {% for mpp in main_project_part_list_right %}
    {% with ec_title=mpp ec_id=mpp.id ec_url="" ec_count=mpp.get_num_questions question_list=mpp.get_questions id_addon=mpp.id ec_box_include="info_box/questions.html" sh_title="" %}
      {% include "layout_elements/ec_header_box.html" %}
    {% endwith %}
  {% endfor %}

</div>

{% endblock %}













