{% load i18n %}


    {% if membership_list %}
        <div class="info_box_content">
          <table class="table">
            {% for m in membership_list %}
            <tr>
              <td>
                <a href="{{ m.from_participant.get_absolute_url}}">{{ m.from_participant.name }}</a>
              </td>
              <td style="width:135px;text-align:right;">{{ m.function }} {% if not m.active %}({% trans "former" %}){% endif %}</td>
              {% if 0 %}
              <td style="width:55px;text-align:right;">
                {% with web_source_list=m.from_participant.web_sources.all %}
                  {% include "layout_elements/menu_web_sources.html" %}
                {% endwith %}
                {% if m.from_participant.get_num_active_user_comments %} 
                  <a href="{{ m.from_participant.get_comments_url }}" style="font-size:11px;">
                    {{ m.from_participant.get_num_active_user_comments }} <i class="icon-comments"></i>
                  </a>
                {% endif %}
              </td>
              {% endif %}
            </tr>
            {% endfor %}
          </table>    
        </div>
      {% else %}
        <span style="font-size:12px;">
        {% trans "No participants available." %}
        </span>
      {% endif %}
    
