  
  <ul class="nav nav-tabs">
  <li class="active">
    <a href="#" style="font-weight:bold;">
    {% if sh_icon %}
        <i class="{{ sh_icon }}"></i>
      {% endif %}
      {{ sh_title }}
      {% if rss_url %}
        &nbsp;<button class="btn btn-mini" id="rss_btn{{ rss_btn_id }}">RSS <i class="icon-rss"></i></button>
        <script>
          $('#rss_btn{{ rss_btn_id }}').click(function() {
            location.href = '{{ rss_url }}';
          });
        </script>
      {% endif %}
      
      {% if sh_ec_id %}&nbsp;
      <button class="btn btn-mini" style="font-size:16px;text-decoration: none;" id="sh_ec_btn_{{ sh_ec_id }}">
        <i class="icon-circle-arrow-down"></i></button>
      {% endif %}
      </a>
      
  </li>
  {% if sh_url_title %}
    <li style="float:right;">
      <a href="{{ sh_url }}" {% if modal_url %}data-toggle="modal"{% endif %}>
        {{ sh_url_title }} <i class="icon-arrow-right"></i>
      </a>
    </li>
  {% endif %}
</ul>

<script>
  $(document).ready(function() {    
    $('#sh_ec_btn_{{ sh_ec_id }}').click(function(e) {
      e.preventDefault();
      $('#{{ sh_ec_id }}').toggle();
    });  
  });
</script>
