{% extends 'base.html' %}
{% load i18n %}

{% block title %} - 404{% endblock %}

{% block content %}


<div class="span6 offset3">

<div class="well" style="margin: 100px 0px 250px 0px; text-align:center;">
  
  {% trans "The page you requested could not be found." %}
</div>

</div>


{% endblock %}