{% load i18n %}

  <div class="section">
  
    <div class="info_box">
      <div class="info_box_content">
        <p>
        {% if activity_list %}
            {% for activity in activity_list %}
            
            <div style="clear:both;">
            <div style="border:1px solid #ddd;margin-bottom:3px;font-size:12px;">
              <div style="padding:7px 12px 7px 12px;background-color: #f9f9f9;" class="comment_header">
                <span style="font-size:13px;font-weight:bold;">{{ activity.get_type_display }}</span>&nbsp; 
                <span style="font-size:11px;">{{ activity.date|date:"d.m.Y H:i" }}</span>
                <br>
                <i class="{{ activity.content_object.get_icon_class }}"></i> 
                <a href="{{ activity.content_object.get_absolute_url }}">{{ activity.content_object }}</a>
              </div>
              
            </div>
          </div>
            
            {% endfor %}
        {% else %}
          <span style="font-size:12px;">
          {% trans "No events available." %}
          </span>
        {% endif %}
        </p>
      </div>
    </div>
  
  </div>