{% load i18n %}


  <div class="info_box" style="background-color: #f9f9f9;padding: 15px;">
      <div class="info_box_content html_text_with_imgs" style="font-size:12px;">
        {% if ppd_with_header %}
        <p style="font-size:16px;font-weight: bold;margin-bottom:15px;">
          <i class="{{ project_part.get_icon_class }}"></i> &nbsp;
          <a href="{{ project_part.get_absolute_url}}" style="color:inherit;">{{ project_part.name }} &nbsp;
          <i class="icon-arrow-right"></i></a>
        </p>
        {% endif %}
        {% if project_part.main_project_parts.count > 0 %}
          <p style="font-size:12px;">
            {% trans "Main Topics" %}:<br>
              {% for main_pp in project_part.main_project_parts.all %}
                <a href="{{ main_pp.get_absolute_url }}">{{ main_pp }}</a><br>
              {% endfor %}
          </p>
        {% endif %}
        
        {{ project_part.description|safe }}
        <div style="clear:both;height:1px;"></div>
        
      </div>
  </div>
