  <div class="info_box ib_text" style="background-color: #eee;">
    {% if ib_title %}
    <div class="info_box_header">
      {{ ib_title }}
    </div>
    {% endif %}
    <div class="info_box_content">
      <p>{{ ib_content|linebreaksbr }}</p>
    </div> 
  </div>