{% load i18n %}


    {% if project_part_list %}
        <div class="info_box_content">
          <table class="table">
            {% for pp in project_part_list %}
            <tr>
              <td style="width:320px;">
                <a href="{{ pp.get_absolute_url}}">{{ pp.name }}</a>
              </td>
            </tr>
            {% endfor %}
          </table>    
        </div>
      {% else %}
        <span style="font-size:12px;">
        {% trans "No project_parts available." %}
        </span>
      {% endif %}