{% load i18n %}
  
  {% if sh_title %}
  {% with sh_title=sh_title sh_ec_id=sh_ec_id sh_icon="icon-inbox" sh_url_title="" %}
    {% include "layout_elements/section_header.html" %}
  {% endwith %}
  {% endif %}
  
  <div class="section" id="{{ sh_ec_id }}">
    <div class="info_box">
      <div class="info_box_content">
      {% if document_list %}
        <table class="table table-striped">
          <tr>
            <th>{% trans "Document" %}</th>
            <th style="text-align: right;">{% trans "Added" %}</th>
          </tr>
          {% for doc in document_list %}
          <tr>
            <td><a href="{{ doc.get_absolute_url }}">{{ doc }}</a>
              <br>
              <span style="display:inline-block;width:75px;">{{ doc.page_set.count }} {% trans "Pages" %}</span> 
              {% if doc.search_tags %}
                {% for tag in doc.search_tags %}
                  <a class="label" href="{{ doc.get_absolute_url }}?q={{ tag|urlencode }}">
                    {{ tag }} <i class="icon-search"></i></a>
                {% endfor %}
                <br>
              {% endif %}
              
              
            </td>
            <td style="text-align: right;">{{ doc.date_added|date:"d.m.Y"}}</td>
          </tr>
          {% endfor %}
        </table>
      {% else %}
        <span style="font-size:12px;">
        {% trans "No documents available." %}
        </span>
      {% endif %}
      </div>
    </div>
  </div>