{% load i18n %}

<div class="span12">
  <h3 style="font-size:20px;float:left;line-height:inherit;margin:0px;"><i class="{{ ph_icon }}"></i> {{ ph_title }}</h3>
  <ul class="breadcrumb" style="float:right;">
  <li><a href="/">Home</a> <span class="divider">/</span></li>
  {% if ph_bc1 %}
  <li><a href="/{{ ph_bc1_url }}">{{ ph_bc1 }}</a> <span class="divider">/</span></li>
  {% endif %}
  {% if ph_bc2 %}
  <li><a href="{{ ph_bc2_url }}">{{ ph_bc2 }}</a> <span class="divider">/</span></li>
  {% endif %}
  <li class="active">{% trans "Research Requests" %}</li>
</ul>
</div>