{% extends 'base.html' %}
{% load i18n %}

{% block title %} - {% trans "Goals" %}{% endblock %}

{% block content %}

{% trans "Goals" as ch_title %}
{% with ch_icon="icon-bullseye" ch_title=ch_title ch_bc1=ch_title %}
{% include "layout_elements/category_header.html" %}
{% endwith %}

</div>

<div class="row">

<div class="span6">

  <div class="section">
    {% include "info_box/site_category_detail.html" %}
  </div>
  
  {% if common_goal_group_list %}
    {% trans "Common" as common_title %}
    {% with sh_title=common_title sh_url_title="" %}
      {% include "layout_elements/section_header.html" %}
    {% endwith %}
    {% for pgg in common_goal_group_list %}
      {% include "info_box/project_goal_group.html" with with_details="yes" %}
    {% endfor %}
  {% endif %}
  
  {% for main_pp in main_project_part_list_left %}
    {% with sh_title=main_pp.name sh_url_title="" %}
      {% include "layout_elements/section_header.html" %}
    {% endwith %}
    {% for pgg in main_pp.projectgoalgroup_set.all %}
      {% include "info_box/project_goal_group.html" with with_details="yes" %}
    {% endfor %}
  {% endfor %}
  
</div>

<div class="span6">
  
  {% for main_pp in main_project_part_list_right %}
    {% with sh_title=main_pp.name sh_url_title="" %}
      {% include "layout_elements/section_header.html" %}
    {% endwith %}
    {% for pgg in main_pp.projectgoalgroup_set.all %}
      {% include "info_box/project_goal_group.html" with with_details="yes" %}
    {% endfor %}
  {% endfor %}
  
</div>

{% endblock %}
















