{% load i18n %}


    {% if participant_list %}
        <div class="info_box_content" id="info_box_participants">
          <table class="table">
            {% for p in participant_list %}
            <tr>
              <td><a href="{{ p.get_absolute_url}}">{{ p.name }}</a></td>
            </tr>
            {% endfor %}
          </table>    
        </div>
      {% else %}
        <span style="font-size:12px;">
        {% trans "No participants available." %}
        </span>
      {% endif %}
    
