{% load i18n %}

{% if web_source_list %}
{% trans "Web-Sources" as sh_title %}
  {% with sh_title=sh_title sh_ec_id="ws_1" sh_icon="icon-globe" sh_url_title="" %}
    {% include "layout_elements/section_header.html" %}
  {% endwith %}  
  
  <div class="section">
    <div class="info_box">
      <div class="info_box_content" id="ws_1">
          {% if web_source_list %}
            <table class="table table-striped">
              {% for ws in web_source_list %}
              <tr>
                <td><i class="icon-external-link"></i> 
                  <a href="{{ ws.url }}" target="_blank">{{ ws.title }}</a>
                </td>
                <td style="text-align: center;width:70px;">{{ ws.date|date:"d.m.Y"}}</td>
                {% if user.is_authenticated %}
                  <td><a href="{{ ws.get_absolute_url }}">A</a></td>
                {% endif %}
              </tr>
              {% endfor %}
            </table>            
          {% else %}
            <span style="font-size:12px;">
            {% trans "No web sources available." %}
            </span>
          {% endif %}
      </div>
    </div>
  </div>
{% endif %}
