{% load i18n %}

<div class="span12">
  <h2 style="float:left;line-height:inherit;margin:0px;"><i class="{{ ch_icon }}"></i> {{ ch_title }}</h2>
  <ul class="breadcrumb" style="float:right;">
  <li><a href="/">Home</a> <span class="divider">/</span></li>
  <li class="active">{{ ch_bc1 }}</li>
</ul>
</div>