{% extends 'base.html' %}
{% load i18n %}

{% block title %} - {% trans "Topics" %}{% endblock %}

{% block rss_url %}
<link rel="alternate" type="application/rss+xml"
   title="RSS" href="{{ request.get_full_path}}rss/" />
{% endblock %}

{% block content %}


{% trans "Topics" as ch_title %}
{% with ch_icon="icon-cogs" ch_title=ch_title ch_bc1=ch_title %}
{% include "layout_elements/category_header.html" %}
{% endwith %}

</div>

<div class="row">

<div class="span6">
  
  <div class="section">
    {% include "info_box/site_category_detail.html" %}
  </div>
  
  {% include "layout_elements/ec_button_group.html" %}
  
  {% for mpp in main_project_part_list_left %}
    {% with ec_title=mpp ec_id=mpp.id ec_url=mpp.get_absolute_url ec_count=mpp.projectpart_set.count project_part_list=mpp.projectpart_set.all with_detail_page_url="yes" ec_box_include="info_box/project_parts.html" %}
      {% include "layout_elements/ec_header_box.html" %}
    {% endwith %}
  {% endfor %}
  
</div>

<div class="span6">
  
  {% if latest_project_part_list %}
    {% trans "New Topics" as sh_title %}
    {% with sh_title=sh_title rss_url="rss/" %}
      {% include "layout_elements/section_header.html" %}
    {% endwith %}
    
    <div class="section">
      {% with ppd_with_header="yes" %}
      {% for project_part in latest_project_part_list %}
        <div style="border: 1px solid #ddd;padding:10px;margin-bottom:5px;">
        {% include "info_box/project_part_detail.html" %}
        </div>
      {% endfor %}
      {% endwith %}
    </div>
  {% endif %}
  
  {% for mpp in main_project_part_list_right %}
    {% with ec_title=mpp ec_id=mpp.id ec_url=mpp.get_absolute_url ec_count=mpp.projectpart_set.count project_part_list=mpp.projectpart_set.all with_detail_page_url="yes" ec_box_include="info_box/project_parts.html" %}
      {% include "layout_elements/ec_header_box.html" %}
    {% endwith %}
  {% endfor %}
  
</div>

{% endblock %}















