
{% if participant_list %}
<div class="btn-group" style="text-align: left;">
  <a class="btn btn-{{ size }} dropdown-toggle" data-toggle="dropdown" data-hover="dropdown" href="#">
    <i class="icon-user"></i> {{ participant_list|length }} <span class="caret"></span>
  </a>
  <ul class="dropdown-menu">
    {% for p in participant_list %}
      <li>
        <a href="{{ p.get_absolute_url}}"><i class="{{ p.get_icon_class }}"></i> {{ p.name }}</a>
      </li>
    {% endfor %}
  </ul>
</div>
{% endif %}
