{% load i18n %}

<div style="border: 1px solid #ddd;margin-bottom:5px;" class="type_div {% if not event.important %}tr_normal_event{% endif %}">

  <table style="width:100%;">
    <tr>
      <td style="width:70px;font-size:12px;padding: 10px;">
          {% if event.not_exact %}({% endif %}{{ event.date|date:"d.m.Y" }}{% if event.not_exact %}){% endif %}
      </td>
      <td style="text-align: center;width:15px;padding: 10px;">
                <i class="{{ event.get_event_type_icon }}"></i>
              </td>
      <td style="font-size:14px;padding: 10px;">
        <a href="{{ event.get_absolute_url}}">{{ event.title }}</a>

    </td></tr>
  </table>
</div>