


<div class="info_box" style="background-color: #eee;padding: 15px;">
      <div class="info_box_content html_text_with_imgs">
        <p style="margin: 0 0 10px;">
          {{ site_category.intro_text|safe }}
          <div style="clear:both;height:1px;"></div>
        </p>
        
        <p style="font-size:12px;margin:0 0 5px;">
          {% for doc in site_category.documents.all %}
            <i class="icon-inbox"></i> <a href="{{ doc.get_absolute_url }}">{{ doc }}</a><br>
          {% endfor %}
        </p>
        <p style="font-size:12px;margin:0 0 5px;">
          {% for ws in site_category.web_sources.all %}
            <i class="icon-globe"></i> <a href="{{ ws.url }}" target="_blank">{{ ws }}</a><br>
          {% endfor %}
        </p>
        
      </div>
    </div>
